@@ -1,3 +1,4 @@
-version = '0.3'
+version = '0.3.1'
+localepath = '/usr/local/share/locale'
 pixpath = '/usr/local/share/pixmaps'
 gladepath = '/usr/local/share/gnomolicious'
