@@ -65,14 +65,14 @@ class GnomoliciousApplet(gnome.applet.Applet):
         # Popup-menu definition and popup-menu callbacks
         self.propxml="""\
 <popup name="button3">
-  <menuitem name="post" verb="Post" label="P_ost on del.icio.us..."
+  <menuitem name="post" verb="Post" label="%s"
     pixtype="stock" pixname="gtk-jump-to" />
-  <menuitem name="pref" verb="Props" label="_Preferences..."
+  <menuitem name="pref" verb="Props" label="%s"
     pixtype="stock" pixname="gtk-properties" />
-  <menuitem name="about" verb="About" label="_About..."
+  <menuitem name="about" verb="About" label="%s"
     pixtype="stock" pixname="gnome-stock-about" />
 </popup>
-"""
+""" % (_('P_ost on del.icio.us...'), _('_Preferences...'), _('_About...'))
         self.verbs = [ ('Props', self.preferences),
                        ('Post', self.post),
                        ('About', self.about) ]
@@ -180,10 +180,7 @@ class GnomoliciousApplet(gnome.applet.Applet):
         posts = delicious.get_urlposts(url)
         for post in posts:
             for tag in post['tags'].split():
-                if tag in tags:
-                    tags[tag] += 1
-                else:
-                    tags[tag] = 1
+                tags[tag] = tags.get(tag, 0) + 1
         lst = tags.items()
         lst.sort(lambda x,y: cmp(x[1], y[1]))
         lst.reverse()
@@ -194,7 +191,13 @@ class GnomoliciousApplet(gnome.applet.Applet):
         if tags:
             self.postwin.entries['popular'].remove(self.populartags_nobuttons)
         for tag, num in tags:
-            btn = gtk.CheckButton(tag)
+            if tag in [x[0] for x in self.tags]:
+                color = "blue"
+            else:
+                color = "black"
+            btn = gtk.CheckButton(tag, False)
+            label = btn.get_children()[0]
+            label.set_markup('<span foreground="%s">%s</span>' % (color, tag))
             btn.connect('toggled', self.on_poptoggled, tag)
             self.populartags_buttons[tag] = btn
             self.postwin.entries['popular'].attach(btn, col, col+1,
@@ -221,7 +224,7 @@ class GnomoliciousApplet(gnome.applet.Applet):
         self.prefwin.show()
 
     def about(self, evt, data=None):
-        about = gnome.ui.About(_("Gnomolicious"),
+        about = gnome.ui.About("Gnomolicious",
                 conf.version, "© 2005 Nicolas Évrard",
                 _('GNOME applet to post on del.icio.us'),
                 ['Nicolas Évrard <nicoe@altern.org>'], [], '', self.logo)
@@ -251,8 +254,11 @@ class GnomoliciousApplet(gnome.applet.Applet):
         url = selection.data
         logger.info('Received url: %s' % url)
         txt = urllib.urlopen(url).read()
-        title = self.title_re.search(txt).groupdict()['title']
-        title = ' '.join(title.split())
+        title_match = self.title_re.search(txt)
+        if title_match:
+            title = ' '.join(title_match.groupdict()['title'].split())
+        else:
+            title = ''
         self.postwin.entries['url'].set_text(url)
         self.postwin.entries['desc'].set_text(title)
         self.update_tags()
